@@ -44,7 +44,7 @@ class entry:
     ep_url: str = ""
     embed_url: str = ""
     stream_url: str = ""
-    ep: int = 0
+    ep: int | float = 0
     latest_ep: int = 0
     quality: str = ""
 
@@ -90,6 +90,18 @@ def keyboard_inter() -> None:
     sys.exit()
 
 
+def parsenum(n: str):
+    """
+    Parse String to either
+    int or float.
+    """
+
+    try:
+        return int(n)
+    except ValueError:
+        return float(n)
+
+
 def read_json(path):
     """
     Read a json file, if
